# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-PPIx-QuoteLike
Version:	0.023
Release:	3.%{__distinit}%{__distvers}
Summary:	Parse Perl string literals and string-literal-like things
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/PPIx-QuoteLike
Source0:	https://cpan.metacpan.org/authors/id/W/WY/WYANT/PPIx-QuoteLike-%{version}.tar.gz
BuildArch:	noarch
# ----------------------------------------------------------------------------
# Module build requirements
# ----------------------------------------------------------------------------
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	perl(lib)
BuildRequires:	perl(Module::Metadata)
# ----------------------------------------------------------------------------
# Module requirements
# ----------------------------------------------------------------------------
BuildRequires:	perl(base)
BuildRequires:	perl(Carp)
BuildRequires:	perl(constant)
BuildRequires:	perl(Encode)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(List::Util)
BuildRequires:	perl(PPI::Document) >= 1.238
BuildRequires:	perl(PPI::Dumper) >= 1.238
BuildRequires:	perl(re)
BuildRequires:	perl(Readonly)
BuildRequires:	perl(Scalar::Util)
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
# ----------------------------------------------------------------------------
# Regular test suite requirements
# ----------------------------------------------------------------------------
BuildRequires:	perl(charnames)
BuildRequires:	perl(open)
BuildRequires:	perl(Test::More) >= 0.88
# ----------------------------------------------------------------------------
# Dependencies
# ----------------------------------------------------------------------------
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(PPI::Dumper) >= 1.238

# Optional functionality
BuildRequires:	perl(PPIx::Regexp)
Requires:	perl(PPIx::Regexp)

%description
This Perl class parses Perl string literals and things that are reasonably like
string literals. Its real reason for being is to find interpolated variables
for Perl::Critic policies and similar code.

%prep
%setup -q -n PPIx-QuoteLike-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%license LICENSES/*
%doc Changes CONTRIBUTING eg/ README
%{perl_vendorlib}/PPIx/
%{_mandir}/man3/PPIx::QuoteLike*.3*

%changelog
* Tue Jul 18 2023 Paul Howarth <paul@city-fan.org> - 0.023-3
- Drop MODULE_COMPAT dependency from Fedora 38 onwards

* Sat Sep 17 2022 Paul Howarth <paul@city-fan.org> - 0.023-2
- Use SPDX-format license tag

* Fri Sep 16 2022 Paul Howarth <paul@city-fan.org> - 0.023-1
- Update to 0.023
  - Update discouragement notice for variables(), and add a TODO in
    t/variables.t for why
  - Correct normalization of ${^FOO} for PPI: if the caret is present the
    braces are not removed

* Sat Apr 16 2022 Paul Howarth <paul@city-fan.org> - 0.022-1
- Update to 0.022
  - Remove 'postderef' argument to new(); postfix dereference is always
    recognized

* Sun Apr  3 2022 Paul Howarth <paul@city-fan.org> - 0.021-1
- Update to 0.021
  - Recognize postfix deref in '@{[ ... ]}' for determining minimum Perl
    version; this recognizes all forms of postfix dereference, including ->%%*,
    ->&*, and ->** (NOTE: for now, this remains a
    PPIx::QuoteLike::Token::Interpolation)
  - Require PPI 1.238 for postfix deref support, and prune code that dealt with
    PPI's old behaviour
  - Postfix %%*, &*, and ** do not interpolate
  - Correct perl_version_introduced() for interpolated postfix scalar deref

* Thu Mar 17 2022 Paul Howarth <paul@city-fan.org> - 0.020-1
- Update to 0.020
  - Correct and optimize the computation of logical column position (the one
    that takes account of tabs)

* Tue Nov 16 2021 Paul Howarth <paul@city-fan.org> - 0.019-1
- Update to 0.019
  - Add CONTRIBUTING file
  - Try to quell weird Win32 test failures that seem to occur only in tests
    where I am using 'use open' to put the standard handles into UTF-8 mode;
    the fix (hopefully) is to do this to the Test::Harness handles at run time
    instead of to the standard handles at compile time

* Fri Oct 22 2021 Paul Howarth <paul@city-fan.org> - 0.018-1
- Update to 0.018
  - Argument postderef is now fatal
  - Correct generation of 'provides' metadata
- Fix dist tags for Alma and Rocky Linux

* Fri Apr 16 2021 Paul Howarth <paul@city-fan.org> - 0.017-1
- Update to 0.017
  - All uses of the postderef argument to new() now warn

* Fri Mar 26 2021 Paul Howarth <paul@city-fan.org> - 0.016-1
- Update to 0.016
  - Add rt.cpan.org back to bug reporting methods; long live RT!
  - Get prerequisites up to snuff, and add xt/author/prereq.t to ensure they
    stay that way
  - Refactor authortest into three, so I do not have to generate stub files to
    test without optional modules

* Sat Feb  6 2021 Paul Howarth <paul@city-fan.org> - 0.015-1
- Update to 0.015
  - Handle <<\EOD and <<~\EOD, which are equivalent to <<'EOD' and
    <<~'EOD', respectively
  - Recognize indented here documents

* Thu Jan 14 2021 Paul Howarth <paul@city-fan.org> - 0.014-1
- Update to 0.014
  - Add Travis CI testing
  - Use GitHub as bug tracker: R.I.P. rt.cpan.org
- Use %%license unconditionally

* Fri Oct  9 2020 Paul Howarth <paul@city-fan.org> - 0.013-1
- Update to 0.013
  - Warn on first use of attribute 'postderef'

* Thu Jul 30 2020 Paul Howarth <paul@city-fan.org> - 0.012-1
- Update to 0.012
  - Remove prototypes from testing subroutines defined in t/*.t

* Tue Mar 31 2020 Paul Howarth <paul@city-fan.org> - 0.011-1
- Update to 0.011
  - Normalize interpolation before feeding to PPI; this produces a
    more-easily-analyzed PPI parse
  - The ->variables() method is now discouraged; it was written to support
    Perl::Critic::Policy::Variables::ProhibitUnusedVarsStricter, but turned out
    to be inadequate for the job
  - Deprecate new() argument postderef
    - At this stage it is only documented as deprecated
    - In the first release after October 1 2020 it will warn on the first use
    - Eventually it will be retracted, and postfix dereferences will always be
      recognized; this is the default behaviour now
  - Correct bracket matchers to accept multiple lines; this was, in some cases,
    causing interpolations to be misclassified as unknown tokens

* Mon Mar  9 2020 Paul Howarth <paul@city-fan.org> - 0.010-1
- Update to 0.010
  - Remove redundant and poorly-performing code introduced in version 0.009

* Fri Feb 28 2020 Paul Howarth <paul@city-fan.org> - 0.009-1
- Update to 0.009
  - Add new() argument index_locations, which causes locations to be indexed
    during the parse; this defaults based on whether a location argument was
    provided, and whether the string being parsed is a PPI::Element
  - Add method statement(), which returns the PPI statement containing the
    string element, or nothing if none
  - Add PPI::Element location methods, to wit: location(), column_number(),
    line_number(), logical_filename(), logical_line_number(), and
    visual_column_number()
  - Add PPIx::QuoteLike::Utils::is_ppi_quotelike_element(), which returns true
    if the argument is a PPI::Element of interest to us
  - All objects now have a variables() method inherited from
    PPIx::QuoteLike::Token, which returns nothing unless overridden; it was
    added to eliminate $elem->can( 'variables' ) ad-hocery
  - Eliminate redirections in POD URL links

* Fri Aug 16 2019 Paul Howarth <paul@city-fan.org> - 0.008-1
- Update to 0.008
  - Fix broken POD links, and add test to ensure they stay fixed

* Mon Jun  3 2019 Paul Howarth <paul@city-fan.org> - 0.007-1
- Update to 0.007
  - Prohibit interpolation inside \N{...}
  - Fix error message in eg/pqldump
  - Allow PPIx::QuoteLike::Utils::__variables() to take a PPI::Element (rather
    than PPI::Node), PPIx::Regexp::Element, PPIx::QuoteLike, or
    PPIx::QuoteLike::Token
  - Add eg/variables

* Tue Jul 10 2018 Paul Howarth <paul@city-fan.org> - 0.006-1
- Update to 0.006
  - Only standalone graphemes and non-characters allowed as delimiters starting
    with Perl 5.29.0
  - Non-ASCII delimiters started working in 5.8.3, so that is what
    perl_version_introduced() returns for them
  - Collateral with all this, accept word characters as delimiters, but only
    with at least one space between the operator and the expression, i.e.
    'qq xyx' is OK, but 'qqxyx' is not

* Fri Jun  1 2018 Paul Howarth <paul@city-fan.org> - 0.005-1
- Initial RPM version
